@@ -12,7 +12,6 @@ from . import (
     PYQT6,
     PYSIDE2,
     PYSIDE6,
-    QtBindingsNotFoundError,
     QtModuleNotInstalledError,
 )
 
@@ -21,28 +20,30 @@ if PYQT5:
         from PyQt5.Qt3DExtras import *
     except ModuleNotFoundError as error:
         raise QtModuleNotInstalledError(
-            name='Qt3DExtras', missing_package='PyQt3D'
+            name="Qt3DExtras",
+            missing_package="PyQt3D",
         ) from error
 elif PYQT6:
     try:
         from PyQt6.Qt3DExtras import *
     except ModuleNotFoundError as error:
         raise QtModuleNotInstalledError(
-            name='Qt3DExtras', missing_package='PyQt6-3D'
+            name="Qt3DExtras",
+            missing_package="PyQt6-3D",
         ) from error
 elif PYSIDE2:
     # https://bugreports.qt.io/projects/PYSIDE/issues/PYSIDE-1026
-    import PySide2.Qt3DExtras as __temp
     import inspect
 
+    import PySide2.Qt3DExtras as __temp
+
     for __name in inspect.getmembers(__temp.Qt3DExtras):
         globals()[__name[0]] = __name[1]
 elif PYSIDE6:
     # https://bugreports.qt.io/projects/PYSIDE/issues/PYSIDE-1026
-    import PySide6.Qt3DExtras as __temp
     import inspect
 
+    import PySide6.Qt3DExtras as __temp
+
     for __name in inspect.getmembers(__temp.Qt3DExtras):
         globals()[__name[0]] = __name[1]
-else:
-    raise QtBindingsNotFoundError()
