@@ -1,7 +1,10 @@
 import pytest
-from qtpy import PYQT6
+
+from qtpy import PYQT6, PYSIDE6
+
 
 @pytest.mark.skipif(PYQT6, reason="Not complete in PyQt6")
+@pytest.mark.skipif(PYSIDE6, reason="Not complete in PySide6")
 def test_qt3dcore():
     """Test the qtpy.Qt3DCore namespace"""
     Qt3DCore = pytest.importorskip("qtpy.Qt3DCore")
